@@ -86,6 +86,22 @@ class Context:
         self.unknown_fields = kwargs
 
 
+class RetentionPolicy:
+    type: Optional[str]
+    duration_days: Optional[int]
+
+    def __init__(
+        self,
+        *,
+        type: Optional[str] = None,
+        duration_days: Optional[int] = None,
+        **kwargs,
+    ) -> None:
+        self.type = type
+        self.duration_days = duration_days
+        self.unknown_fields = kwargs
+
+
 class Details:
     name: Optional[str]
     new_value: Optional[Union[str, List[str], Dict[str, Any]]]
@@ -103,6 +119,7 @@ class Details:
     origin_team: Optional[str]
     target_team: Optional[str]
     is_internal_integration: Optional[bool]
+    cleared_resolution: Optional[str]
     app_owner_id: Optional[str]
     bot_scopes: Optional[List[str]]
     new_scopes: Optional[List[str]]
@@ -139,6 +156,9 @@ class Details:
     channel_id: Optional[str]
     added_team_id: Optional[str]
     unknown_fields: Dict[str, Any]
+    is_token_rotation_enabled_app: Optional[bool]
+    old_retention_policy: Optional[RetentionPolicy]
+    new_retention_policy: Optional[RetentionPolicy]
 
     def __init__(
         self,
@@ -152,13 +172,14 @@ class Details:
         non_sso_only: Optional[bool] = None,
         type: Optional[str] = None,
         is_workflow: Optional[bool] = None,
-        inviter: Optional[User] = None,
-        kicker: Optional[User] = None,
+        inviter: Optional[Union[Dict[str, Any], User]] = None,
+        kicker: Optional[Union[Dict[str, Any], User]] = None,
         shared_to: Optional[str] = None,
         reason: Optional[str] = None,
         origin_team: Optional[str] = None,
         target_team: Optional[str] = None,
         is_internal_integration: Optional[bool] = None,
+        cleared_resolution: Optional[str] = None,
         app_owner_id: Optional[str] = None,
         bot_scopes: Optional[List[str]] = None,
         new_scopes: Optional[List[str]] = None,
@@ -194,6 +215,9 @@ class Details:
         external_user_email: Optional[str] = None,
         channel_id: Optional[str] = None,
         added_team_id: Optional[str] = None,
+        is_token_rotation_enabled_app: Optional[bool] = None,
+        old_retention_policy: Optional[Union[Dict[str, Any], RetentionPolicy]] = None,
+        new_retention_policy: Optional[Union[Dict[str, Any], RetentionPolicy]] = None,
         **kwargs,
     ) -> None:
         self.name = name
@@ -205,13 +229,14 @@ class Details:
         self.non_sso_only = non_sso_only
         self.type = type
         self.is_workflow = is_workflow
-        self.inviter = inviter
-        self.kicker = kicker
+        self.inviter = inviter if isinstance(inviter, User) else User(**inviter)
+        self.kicker = kicker if isinstance(kicker, User) else User(**kicker)
         self.shared_to = shared_to
         self.reason = reason
         self.origin_team = origin_team
         self.target_team = target_team
         self.is_internal_integration = is_internal_integration
+        self.cleared_resolution = cleared_resolution
         self.app_owner_id = app_owner_id
         self.bot_scopes = bot_scopes
         self.new_scopes = new_scopes
@@ -248,6 +273,17 @@ class Details:
         self.external_user_email = external_user_email
         self.channel_id = channel_id
         self.added_team_id = added_team_id
+        self.is_token_rotation_enabled_app = is_token_rotation_enabled_app
+        self.old_retention_policy = (
+            old_retention_policy
+            if isinstance(old_retention_policy, RetentionPolicy)
+            else RetentionPolicy(**old_retention_policy)
+        )
+        self.new_retention_policy = (
+            new_retention_policy
+            if isinstance(new_retention_policy, RetentionPolicy)
+            else RetentionPolicy(**new_retention_policy)
+        )
 
 
 class App:
